@@ -308,7 +308,12 @@ def add_column(path, table, col_name, col_type, fk, fk_col, not_null_default):
 @click.argument("column")
 @click.argument("other_table", required=False)
 @click.argument("other_column", required=False)
-def add_foreign_key(path, table, column, other_table, other_column):
+@click.option(
+    "--ignore",
+    is_flag=True,
+    help="If foreign key already exists, do nothing",
+)
+def add_foreign_key(path, table, column, other_table, other_column, ignore):
     """
     Add a new foreign key constraint to an existing table. Example usage:
 
@@ -318,7 +323,37 @@ def add_foreign_key(path, table, column, other_table, other_column):
     """
     db = sqlite_utils.Database(path)
     try:
-        db[table].add_foreign_key(column, other_table, other_column)
+        db[table].add_foreign_key(column, other_table, other_column, ignore=ignore)
+    except AlterError as e:
+        raise click.ClickException(e)
+
+
+@cli.command(name="add-foreign-keys")
+@click.argument(
+    "path",
+    type=click.Path(exists=True, file_okay=True, dir_okay=False, allow_dash=False),
+    required=True,
+)
+@click.argument("foreign_key", nargs=-1)
+def add_foreign_keys(path, foreign_key):
+    """
+    Add multiple new foreign key constraints to a database. Example usage:
+
+    \b
+    sqlite-utils add-foreign-keys my.db \\
+        books author_id authors id \\
+        authors country_id countries id
+    """
+    db = sqlite_utils.Database(path)
+    if len(foreign_key) % 4 != 0:
+        raise click.ClickException(
+            "Each foreign key requires four values: table, column, other_table, other_column"
+        )
+    tuples = []
+    for i in range(len(foreign_key) // 4):
+        tuples.append(tuple(foreign_key[i * 4 : (i * 4) + 4]))
+    try:
+        db.add_foreign_keys(tuples)
     except AlterError as e:
         raise click.ClickException(e)
 
@@ -852,6 +887,147 @@ def rows(ctx, path, dbtable, nl, arrays, csv, no_headers, table, fmt, json_cols)
     )
 
 
+@cli.command()
+@click.argument(
+    "path",
+    type=click.Path(file_okay=True, dir_okay=False, allow_dash=False),
+    required=True,
+)
+@click.argument("table")
+@click.option(
+    "--type",
+    type=(str, str),
+    multiple=True,
+    help="Change column type to X",
+)
+@click.option("--drop", type=str, multiple=True, help="Drop this column")
+@click.option(
+    "--rename", type=(str, str), multiple=True, help="Rename this column to X"
+)
+@click.option("-o", "--column-order", type=str, multiple=True, help="Reorder columns")
+@click.option("--not-null", type=str, multiple=True, help="Set this column to NOT NULL")
+@click.option(
+    "--not-null-false", type=str, multiple=True, help="Remove NOT NULL from this column"
+)
+@click.option("--pk", type=str, multiple=True, help="Make this column the primary key")
+@click.option(
+    "--pk-none", is_flag=True, help="Remove primary key (convert to rowid table)"
+)
+@click.option(
+    "--default",
+    type=(str, str),
+    multiple=True,
+    help="Set default value for this column",
+)
+@click.option(
+    "--default-none", type=str, multiple=True, help="Remove default from this column"
+)
+@click.option(
+    "--drop-foreign-key",
+    type=str,
+    multiple=True,
+    help="Drop this foreign key constraint",
+)
+@click.option("--sql", is_flag=True, help="Output SQL without executing it")
+def transform(
+    path,
+    table,
+    type,
+    drop,
+    rename,
+    column_order,
+    not_null,
+    not_null_false,
+    pk,
+    pk_none,
+    default,
+    default_none,
+    drop_foreign_key,
+    sql,
+):
+    "Transform a table beyond the capabilities of ALTER TABLE"
+    db = sqlite_utils.Database(path)
+    types = {}
+    kwargs = {}
+    for column, ctype in type:
+        if ctype.upper() not in VALID_COLUMN_TYPES:
+            raise click.ClickException(
+                "column types must be one of {}".format(VALID_COLUMN_TYPES)
+            )
+        types[column] = ctype.upper()
+
+    not_null_dict = {}
+    for column in not_null:
+        not_null_dict[column] = True
+    for column in not_null_false:
+        not_null_dict[column] = False
+
+    default_dict = {}
+    for column, value in default:
+        default_dict[column] = value
+    for column in default_none:
+        default_dict[column] = None
+
+    kwargs["types"] = types
+    kwargs["drop"] = set(drop)
+    kwargs["rename"] = dict(rename)
+    kwargs["column_order"] = column_order or None
+    kwargs["not_null"] = not_null_dict
+    if pk:
+        if len(pk) == 1:
+            kwargs["pk"] = pk[0]
+        else:
+            kwargs["pk"] = pk
+    elif pk_none:
+        kwargs["pk"] = None
+    kwargs["defaults"] = default_dict
+    if drop_foreign_key:
+        kwargs["drop_foreign_keys"] = drop_foreign_key
+
+    if sql:
+        for line in db[table].transform_sql(**kwargs):
+            click.echo(line)
+    else:
+        db[table].transform(**kwargs)
+
+
+@cli.command()
+@click.argument(
+    "path",
+    type=click.Path(file_okay=True, dir_okay=False, allow_dash=False),
+    required=True,
+)
+@click.argument("table")
+@click.argument("columns", nargs=-1, required=True)
+@click.option(
+    "--table", "other_table", help="Name of the other table to extract columns to"
+)
+@click.option("--fk-column", help="Name of the foreign key column to add to the table")
+@click.option(
+    "--rename",
+    type=(str, str),
+    multiple=True,
+    help="Rename this column in extracted table",
+)
+def extract(
+    path,
+    table,
+    columns,
+    other_table,
+    fk_column,
+    rename,
+):
+    "Extract one or more columns into a separate table"
+    db = sqlite_utils.Database(path)
+    kwargs = dict(
+        columns=columns,
+        table=other_table,
+        fk_column=fk_column,
+        rename=dict(rename),
+    )
+    db[table].extract(**kwargs)
+
+
 @cli.command(name="insert-files")
 @click.argument(
     "path",
