@@ -5,6 +5,7 @@ from sqlite_utils.db import (
     AlterError,
     NoObviousTable,
     ForeignKey,
+    Table,
 )
 from sqlite_utils.utils import sqlite3
 import collections
@@ -348,7 +349,9 @@ def test_add_foreign_key(fresh_db):
         ]
     )
     assert [] == fresh_db["books"].foreign_keys
-    fresh_db["books"].add_foreign_key("author_id", "authors", "id")
+    t = fresh_db["books"].add_foreign_key("author_id", "authors", "id")
+    # Ensure it returned self:
+    assert isinstance(t, Table) and t.name == "books"
     assert [
         ForeignKey(
             table="books", column="author_id", other_table="authors", other_column="id"
@@ -379,6 +382,13 @@ def test_add_foreign_key_error_if_already_exists(fresh_db):
     assert "Foreign key already exists for author_id => authors.id" == ex.value.args[0]
 
 
+def test_add_foreign_key_no_error_if_exists_and_ignore_true(fresh_db):
+    fresh_db["books"].insert({"title": "Hedgehogs of the world", "author_id": 1})
+    fresh_db["authors"].insert({"id": 1, "name": "Sally"}, pk="id")
+    fresh_db["books"].add_foreign_key("author_id", "authors", "id")
+    fresh_db["books"].add_foreign_key("author_id", "authors", "id", ignore=True)
+
+
 def test_add_foreign_keys(fresh_db):
     fresh_db["authors"].insert_all(
         [{"id": 1, "name": "Sally"}, {"id": 2, "name": "Asheesh"}], pk="id"
@@ -561,7 +571,7 @@ def test_bulk_insert_more_than_999_values(fresh_db):
                 "c6": 6,
                 "c7": 7,
                 "c8": 8,
-                "c8": 9,
+                "c9": 9,
                 "c10": 10,
                 "c11": 11,
             }
@@ -736,7 +746,7 @@ def test_insert_thousands_using_generator(fresh_db):
     assert 10000 == fresh_db["test"].count
 
 
-def test_insert_thousands_raises_exception_wtih_extra_columns_after_first_100(fresh_db):
+def test_insert_thousands_raises_exception_with_extra_columns_after_first_100(fresh_db):
     # https://github.com/simonw/sqlite-utils/issues/139
     with pytest.raises(Exception, match="table test has no column named extra"):
         fresh_db["test"].insert_all(
